pub enum BybitCancelOrderError {
MissingOrderId,
PostCancelLookup {
source: Error,
},
}Expand description
Error raised after Bybit accepts a cancel request envelope.
Variants
MissingOrderId
Bybit accepted the request envelope, but did not return an order ID.
PostCancelLookup
Bybit returned an order ID, but the immediate order lookup failed.