pub enum BybitModifyOrderError {
MissingOrderId,
PostModifyLookup {
source: Error,
},
}Expand description
Error raised after Bybit accepts a modify request envelope.
Variants
MissingOrderId
Bybit accepted the request envelope, but did not return an order ID.
PostModifyLookup
Bybit returned an order ID, but the immediate order lookup failed.