pub enum BybitSubmitOrderError {
MissingOrderId,
Rejected {
reason: String,
},
PostSubmitLookup {
source: Error,
},
}Expand description
Error raised while submitting a Bybit order.
Variants
MissingOrderId
Bybit accepted the request envelope, but did not return an order ID.
Rejected
Bybit returned an order that is rejected with no fills.
PostSubmitLookup
Bybit returned an order ID, but the immediate order lookup failed.